@@ -51,15 +51,15 @@ test.ascii <- function() {
     # (better than silently getting an empty proto.)
     book4 <- checkException( readASCII( tutorial.AddressBook, file(out.file, "rt")))
 
-    # Test does not work on windows because of chmod
-    if(!grepl("mingw", R.Version()$platform)){
-        # Verify that we get an exception if the file is not readable.
-        old.mode <- file.info(out.file)[["mode"]]
-        Sys.chmod(out.file, "0000")
-        book5 <- checkException( readASCII( tutorial.AddressBook, file(out.file, "rb")))
-        # Set the permissions back to ensure the file is cleaned up properly.
-        Sys.chmod(out.file, old.mode)
-    }
+    ## # Test does not work on windows because of chmod
+    ## if(!grepl("mingw", R.Version()$platform)){
+    ##     # Verify that we get an exception if the file is not readable.
+    ##     old.mode <- file.info(out.file)[["mode"]]
+    ##     Sys.chmod(out.file, "0000")
+    ##     book5 <- checkException( readASCII( tutorial.AddressBook, file(out.file, "rb")))
+    ##     # Set the permissions back to ensure the file is cleaned up properly.
+    ##     Sys.chmod(out.file, old.mode)
+    ## }
 
     # Verify that we get an exception if the file is not parseable.
     out.file2 <- tempfile()
